<template>
    <div
        class="full-page"
        element-loading-text="数据加载中..."
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)"
        v-loading.fullscreen.lock="markLoading"
    >
        <div class="search-container">
            <el-form :inline="true" :model="parameter">
                <el-row :gutter="10">
                    <el-col :span="6">
                        <el-form-item style="width: 100%" label="姓名">
                            <el-input
                                clearable
                                v-model="querys[0].value"
                                placeholder="请输入姓名"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="6">
                        <el-form-item style="width: 100%" label="电话">
                            <el-input
                                clearable
                                v-model="querys[1].value"
                                placeholder="请输入电话"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button
                            type="primary"
                            @click="getData(1)"
                            icon="el-icon-search"
                            >查询</el-button
                        >
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" :class="['main-table-container', 'flex']">
            <el-col
                :span="24"
                class="table-container"
                ref="contentPanel"
                style="padding: 20px"
            >
                <div style="margin-bottom: 10px" ref="btnPanel">
                    <el-button
                        icon="el-icon-plus"
                        type="primary"
                        class="btn btn-plus"
                        @click="handleAdd"
                    >
                        {{ this.$t('common.add') }}
                    </el-button>
                    <el-button
                        slot="reference"
                        icon="el-icon-delete"
                        type="danger"
                        class="btn btn-delete"
                        @click="handleDelete('deletes')"
                        :disabled="deleteIds ? false : true"
                    >
                        {{ this.$t('common.delete') }}
                    </el-button>
                    <el-button
                        type="warning"
                        icon="el-icon-download"
                        @click="downFile"
                        >导出</el-button
                    >
                    <el-upload
                        class="upload"
                        style="margin: 0 10px;display: inline-block;"
                        :action="actionUrl + '/base/team/member/importExcel'"
                        :show-file-list="false"
                        :before-upload="beforeUpload"
                        :on-success="handleAvatarSuccess"
                        :on-error="handleAvatarError"
                        :headers="header"
                    >
                        <el-button type="success" icon="el-icon-upload2"
                            >导入</el-button
                        >
                    </el-upload>
                    <el-button
                        type="warning"
                        icon="el-icon-download"
                        @click="downModel"
                        >模板下载</el-button
                    >
                </div>
                <div class="table-wrapper">
                    <el-table
                        height="100%"
                        row-key="id"
                        align="center"
                        :data="tableData"
                        :cell-style="{'text-align': 'center'}"
                        style="min-width: 100%; overflow: auto"
                        :header-cell-style="{'text-align': 'center'}"
                        v-loading="loading"
                        @selection-change="handleSelectionChange"
                        ref="table"
                    >
                        <el-table-column
                            type="selection"
                            width="55"
                            align="center"
                            :selectable="selectable"
                        ></el-table-column>
                        <el-table-column
                            type="index"
                            width="60"
                            label="序号"
                        ></el-table-column>
                        <el-table-column
                            prop="name"
                            label="姓名"
                        ></el-table-column>
                        <el-table-column
                            prop="phone"
                            label="联系电话"
                        ></el-table-column>
                        <!-- <el-table-column prop="idcard" label="身份证号"></el-table-column> -->
                        <!-- <el-table-column prop="detailAddress" label="现居住地详细地址"></el-table-column> -->
                        <!-- <el-table-column prop="createTime" label="备案时间"></el-table-column> -->
                        <el-table-column label="操作">
                            <template v-slot="{row}">
                                <el-link
                                    type="primary"
                                    :underline="false"
                                    style="margin: 0 10px"
                                    class="cloumn-btn"
                                    @click="handleEdit(row)"
                                >
                                    编辑
                                </el-link>
                                <el-link
                                    type="danger"
                                    :underline="false"
                                    class="cloumn-btn"
                                    @click="handleDelete('delete', row)"
                                >
                                    删除
                                </el-link>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination
                    ref="paginationPanel"
                    style="margin-top: 10px"
                    :pageResult="pageResult"
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                />
                <personal-dialog
                    ref="formDialog"
                    @getData="getData"
                ></personal-dialog>
            </el-col>
        </el-row>
    </div>
</template>
<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import PersonalDialog from './PersonalDialog.vue'
import Personal from '@/api/basicConfiguration/Personal'

export default {
    name: 'Personal',
    components: {
        pagination,
        PersonalDialog,
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            tableMaxHeight: 400,
            tableData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'name',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'phone',
                    relation: 'AND',
                    value: '',
                },
            ],
            reqData: {
                querys: [],
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
            },
            tableLoading: false,
            deleteIds: '',
            parameter: {
                size: 20,
                page: 1,
            },
            actionUrl: '',
        }
    },
    created() {
        // this.fljbList = dictUtils.getDictItemsFromCache('fljb')
        this.actionUrl = window.context.portal
        this.getData()
    },
    methods: {
        selectable(row) {
            if (row.isDele === '1') {
                return false
            } else {
                return true
            }
        },
        //获取数据
        getData(page) {
            if (page) {
                this.reqData.pageBean.page = page
            }
            this.reqData.querys = []
            if (this.querys[0].value) {
                this.reqData.querys.push(this.querys[0])
            }
            if (this.querys[1].value) {
                this.reqData.querys.push(this.querys[1])
            }
            this.tableLoading = true
            Personal.dataQuery(this.reqData, (res) => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
                // this.tableData.forEach(e => {
                //     this.fljbList.forEach(f => {
                //         if (e.level == f.value) {
                //             e.levelName = f.name
                //         }
                //     })
                // })
            })
        },

        // 编辑
        handleEdit(item) {
            this.$refs.formDialog.edit(item.id)
        },
        //启用or禁止
        enableOrProhibit(val) {
            Personal.enableDisable({id: val.id}, (res) => {
                if (res.state) {
                    this.$message.success(
                        val.status === '0'
                            ? '启用成功'
                            : val.status === '1'
                            ? '禁用成功'
                            : ''
                    )
                    this.getData()
                }
            })
        },
        //获取删除数据id集合
        handleSelectionChange(val) {
            let arr = val.map((item) => item.id)
            this.deleteIds = arr.join(',')
            console.log(this.deleteIds)
        },
        //删除
        handleDelete(type, val) {
            console.log(val)
            this.$confirm('确认删除吗？', this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'warning',
            }).then(() => {
                this.markLoading = true
                if (type === 'delete') {
                    Personal.remove(val.id, (res) => {
                        if (res.state) {
                            this.getData()
                            this.$message.success('删除成功')
                            this.markLoading = false
                        } else {
                            this.markLoading = false
                        }
                    })
                } else {
                    Personal.batchRemove(this.deleteIds, (res) => {
                        if (res.state) {
                            this.getData()
                            this.$message.success('删除成功')
                            this.markLoading = false
                        } else {
                            this.markLoading = false
                        }
                    })
                }
            })
        },
        handleSizeChange(val) {
            this.reqData.pageBean.pageSize = val
            this.getData()
        },
        handleCurrentChange(val) {
            this.reqData.pageBean.page = val
            this.getData()
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        // 文件上传前
        beforeUpload() {
            this.tableLoading = true
        },
        //上传成功
        handleAvatarSuccess(res, file) {
            //提示
            this.$notify({
                type: 'success',
                message: this.$t('导入成功!'),
                duration: 2000,
            })
            this.getData() //调用用页面查询接口，刷新数据
        },
        downFile() {
            Personal.exportFile(
                {
                    ...this.reqData,
                    pageBean: {
                        pageSize: -1,
                    },
                },
                () => {}
            )
        },
        //上传失败
        handleAvatarError(err, file, fileList) {
            //提示
            this.$notify({
                type: 'error',
                message: this.$t('导入失败!'),
                duration: 2000,
            })
            this.tableLoading = false
        },
        // 模板下载
        downModel() {
            window.open(
                this.actionUrl + '/base/team/member/downModel',
                '_blank'
            )
        },
    },
}
</script>
<style lang='scss' scoped>
@import '~@/assets/css/element-variables.scss';
@import '~@/assets/css/common.scss';

.table-wrapper {
    height: calc(100% - 170px);
}
</style>
